@@ -24,7 +24,7 @@ from fanstatic import Library, Resource
 # import Zope3 packages
 
 # import local packages
-from ztfy.jqueryui import jquery_alerts, jquery_jsonrpc, jquery_color
+from ztfy.jqueryui import jquery_color
 from ztfy.skin import ztfy_skin
 
 
@@ -34,6 +34,6 @@ ztfy_thesaurus_css = Resource(library, 'css/ztfy.thesaurus.css')
 
 ztfy_thesaurus = Resource(library, 'js/ztfy.thesaurus.js',
                           minified='js/ztfy.thesaurus.min.js',
-                          depends=[ztfy_skin, jquery_alerts, jquery_jsonrpc, jquery_color,
+                          depends=[ztfy_skin, jquery_color,
                                    ztfy_thesaurus_css],
                           bottom=True)
