@@ -80,7 +80,8 @@ class IThesaurusInfo(IThesaurusInfoBase):
                      description=_("thesaurus-catalog-description", "Inner thesaurus catalog, used for full-text indexing"),
                      schema=ICatalog)
 
-    def findTerms(self, query=None, extract=None, autoexpand='on_miss', glob='end', limit=None, exact=False):
+    def findTerms(self, query=None, extract=None, autoexpand='on_miss', glob='end', limit=None,
+                  exact=False, exact_only=False):
         """Get terms matching given query and parent
         
         @param query: the text query
