@@ -24,7 +24,7 @@ from zope.dublincore.interfaces import IZopeDublinCore
 # import local interfaces
 from ztfy.thesaurus.interfaces.extension import IThesaurusTermExtension
 from ztfy.thesaurus.interfaces.thesaurus import IThesaurusExtractInfo
-from ztfy.thesaurus.interfaces.term import IThesaurusTerm, IThesaurusLoaderTerm
+from ztfy.thesaurus.interfaces.term import IThesaurusTerm, IThesaurusLoaderTerm, STATUS_PUBLISHED
 from ztfy.thesaurus.interfaces.tree import INode
 
 # import Zope3 packages
@@ -40,11 +40,11 @@ from ztfy.utils.timezone import tztime
 from ztfy.utils.unicode import translateString
 
 
-REVERSE_LINK_ATTRIBUTES = { 'generic': 'specifics',
-                            'usage': 'used_for' }
+REVERSE_LINK_ATTRIBUTES = {'generic': 'specifics',
+                           'usage': 'used_for'}
 
-REVERSE_LIST_ATTRIBUTES = { 'specifics': 'generic',
-                            'used_for': 'usage' }
+REVERSE_LIST_ATTRIBUTES = {'specifics': 'generic',
+                           'used_for': 'usage'}
 
 
 class ThesaurusTerm(Persistent, Contained):
@@ -97,13 +97,15 @@ class ThesaurusTerm(Persistent, Contained):
     @property
     def caption(self):
         if self._usage:
-            return '%s [ %s ]' % (self._usage.label,
-                                  ', '.join((term.label for term in self._usage._used_for)))
+            label = self._usage.label
+            terms = [term.label for term in self._usage.used_for if term.status == STATUS_PUBLISHED]
         elif self._used_for:
-            return '%s [ %s ]' % (self.label,
-                                  ', '.join((term.label for term in self._used_for)))
+            label = self.label
+            terms = [term.label for term in self._used_for if term.status == STATUS_PUBLISHED]
         else:
-            return self.label
+            label = self.label
+            terms = []
+        return label + (' [ %s ]' % ', '.join(terms) if terms else '')
 
     @property
     def generic(self):
