@@ -284,29 +284,32 @@ class Thesaurus(Persistent, Contained):
                 ITransactionManager(self).savepoint()
 
     def resetTopTerms(self):
-        self.top_terms = [ term for term in self.terms.itervalues()
-                           if (not term.generic) and (not term.usage) ]
+        self.top_terms = [term for term in self.terms.itervalues()
+                          if (not term.generic) and (not term.usage)]
 
-    def findTerms(self, query=None, extract=None, autoexpand='on_miss', glob='end', limit=None, exact=False):
+    def findTerms(self, query=None, extract=None, autoexpand='on_miss', glob='end', limit=None,
+                  exact=False, exact_only=False):
+        assert exact or (not exact_only)
         query_util = getUtility(IQuery)
         terms = []
         if exact:
             search = ThesaurusValueSearch((self.catalog, 'base_label'),
                                           translateString(query, escapeSlashes=True, forceLower=True, spaces=' '))
             terms = list(query_util.searchResults(search))
-        start = ''
-        end = ''
-        if '*' not in query:
-            if glob in ('start', 'both'):
-                start = u'*'
-            if glob in ('end', 'both'):
-                end = u'*'
-        search = ThesaurusIndexSearch((self.catalog, 'label'), {'query': u' '.join((u'%s%s%s' % (start, m, end)
-                                                                                    for m in query.split()
-                                                                                          if len(m) > 2)),
-                                                                'autoexpand': autoexpand,
-                                                                'ranking': False})
-        terms += sorted(query_util.searchResults(search, limit=limit), key=lambda x: x.label)
+        if not exact_only:
+            start = ''
+            end = ''
+            if '*' not in query:
+                if glob in ('start', 'both'):
+                    start = u'*'
+                if glob in ('end', 'both'):
+                    end = u'*'
+            search = ThesaurusIndexSearch((self.catalog, 'label'), {'query': u' '.join((u'%s%s%s' % (start, m, end)
+                                                                                        for m in query.split()
+                                                                                              if len(m) > 2)),
+                                                                    'autoexpand': autoexpand,
+                                                                    'ranking': False})
+            terms += sorted(query_util.searchResults(search, limit=limit), key=lambda x: x.label)
         if extract:
             terms = [term for term in terms
                                    if extract in term.extracts]
